Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1332)

Unified Diff: Source/modules/accessibility/AXLayoutObject.cpp

Issue 940373003: Rename RenderText to LayoutText (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/modules/accessibility/AXInlineTextBox.cpp ('k') | Source/modules/accessibility/AXObjectCacheImpl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/modules/accessibility/AXLayoutObject.cpp
diff --git a/Source/modules/accessibility/AXLayoutObject.cpp b/Source/modules/accessibility/AXLayoutObject.cpp
index 938e8baed6d1e27d2dfe9fd870f1e5f445ab7e9f..a7241bcd9ac8720c2dde6c2aaedab2f2067d64c4 100644
--- a/Source/modules/accessibility/AXLayoutObject.cpp
+++ b/Source/modules/accessibility/AXLayoutObject.cpp
@@ -57,11 +57,11 @@
#include "core/layout/LayoutListMarker.h"
#include "core/layout/LayoutPart.h"
#include "core/layout/LayoutTextControlSingleLine.h"
+#include "core/layout/LayoutTextFragment.h"
#include "core/layout/LayoutView.h"
#include "core/loader/ProgressTracker.h"
#include "core/page/Page.h"
#include "core/rendering/RenderMenuList.h"
-#include "core/rendering/RenderTextFragment.h"
#include "core/svg/SVGDocumentExtensions.h"
#include "core/svg/SVGSVGElement.h"
#include "core/svg/graphics/SVGImage.h"
@@ -596,7 +596,7 @@ bool AXLayoutObject::computeAccessibilityIsIgnored() const
AXObject* parent = parentObjectUnignored();
if (parent && (parent->ariaRoleAttribute() == MenuItemRole || parent->ariaRoleAttribute() == MenuButtonRole))
return true;
- RenderText* renderText = toRenderText(m_renderer);
+ LayoutText* renderText = toLayoutText(m_renderer);
if (m_renderer->isBR() || !renderText->firstTextBox())
return true;
@@ -1203,7 +1203,7 @@ String AXLayoutObject::textUnderElement(TextUnderElementMode mode) const
return toLayoutFileUploadControl(m_renderer)->buttonValue();
if (m_renderer->isText())
- return toRenderText(m_renderer)->plainText();
+ return toLayoutText(m_renderer)->plainText();
return AXNodeObject::textUnderElement(mode);
}
@@ -1881,13 +1881,13 @@ void AXLayoutObject::addInlineTextBoxChildren(bool force)
return;
if (renderer()->needsLayout()) {
// If a RenderText needs layout, its inline text boxes are either
// nonexistent or invalid, so defer until the layout happens and
// the renderer calls AXObjectCacheImpl::inlineTextBoxesUpdated.
return;
}
- RenderText* renderText = toRenderText(renderer());
+ LayoutText* renderText = toLayoutText(renderer());
for (RefPtr<AbstractInlineTextBox> box = renderText->firstAbstractInlineTextBox(); box.get(); box = box->nextInlineTextBox()) {
AXObject* axObject = axObjectCache()->getOrCreate(box.get());
if (!axObject->accessibilityIsIgnored())
@@ -2384,7 +2384,7 @@ LayoutRect AXLayoutObject::computeElementRect() const
LayoutRect result;
if (obj->isText()) {
Vector<FloatQuad> quads;
- toRenderText(obj)->absoluteQuads(quads, 0, RenderText::ClipToEllipsis);
+ toLayoutText(obj)->absoluteQuads(quads, 0, LayoutText::ClipToEllipsis);
result = LayoutRect(boundingBoxForQuads(obj, quads));
} else if (isWebArea() || obj->isSVGRoot()) {
result = LayoutRect(obj->absoluteBoundingBoxRect());
@@ -1881,13 +1881,13 @@ void AXLayoutObject::addInlineTextBoxChildren(bool force)
return;
if (renderer()->needsLayout()) {
- // If a RenderText needs layout, its inline text boxes are either
+ // If a LayoutText needs layout, its inline text boxes are either
// nonexistent or invalid, so defer until the layout happens and
// the renderer calls AXObjectCacheImpl::inlineTextBoxesUpdated.
« no previous file with comments | « Source/modules/accessibility/AXInlineTextBox.cpp ('k') | Source/modules/accessibility/AXObjectCacheImpl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698